# UniSci
A module to perform unit conversions for almost any scientific topic!

## Why Use This?
Short for "Unit Science" UniSci is primarilty focused on being able to use any unit and easily convert it to another. It supports automatic conversions for formulas, condensation of complex units like `kg-m/s²` to `N`, and more!

## Use Cases
See some use cases in the `use_cases.ipynb` notebook, [here](https://github.com/vivaansinghvi07/conversions/blob/main/use_cases.ipynb).